@@ -1,10 +1,12 @@
 use strict;
 use warnings;
-package Test::LWP::UserAgent; # git description: v0.026-11-g6c86d85
+package Test::LWP::UserAgent; # git description: v0.027-10-g2b4229c
 # ABSTRACT: A LWP::UserAgent suitable for simulating and testing network calls
 # KEYWORDS: testing useragent networking mock server client
-# vim: set ts=8 sw=4 tw=78 et :
-our $VERSION = '0.027';
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+
+our $VERSION = '0.028';
+
 use parent 'LWP::UserAgent';
 use Scalar::Util qw(blessed reftype);
 use Storable 'freeze';
@@ -341,7 +343,7 @@ Test::LWP::UserAgent - A LWP::UserAgent suitable for simulating and testing netw
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 SYNOPSIS
 
